@@ -173,8 +173,7 @@ class Consumer(messaging.Consumer):
 
 class ConsumerSet(messaging.Consumer):
 
-    def __init__(self, connection, from_dict=None, consumers=None,
-            callbacks=None, **kwargs):
+    def __init__(self, connection, from_dict=None, consumers=None, **kwargs):
         self.backend = connection.channel()
 
         queues = []
