@@ -13,9 +13,12 @@ class test_StdChannel(TestCase):
     def setUp(self):
         self.conn = BrokerConnection("memory://")
         self.channel = self.conn.channel()
+        self.channel.queues.clear()
+        self.conn.connection.state.clear()
 
     def test_Consumer(self):
         q = Queue("foo")
+        print(self.channel.queues)
         cons = self.channel.Consumer(q)
         self.assertIsInstance(cons, Consumer)
         self.assertIs(cons.channel, self.channel)
