@@ -25,6 +25,7 @@ from boto.sdb.connection import SDBConnection
 from boto.sqs.connection import SQSConnection
 from boto.sqs.message import Message
 
+from ..exceptions import StdChannelError
 from ..utils import cached_property, uuid
 from ..utils.encoding import safe_str
 
@@ -195,7 +196,8 @@ class Channel(virtual.Channel):
     def _delete(self, queue, *args):
         """delete queue by name."""
         self._queue_cache.pop(queue, None)
-        self.table.queue_delete(queue)
+        if self.supports_fanout:
+            self.table.queue_delete(queue)
         super(Channel, self)._delete(queue)
 
     def exchange_delete(self, exchange, **kwargs):
@@ -343,4 +345,4 @@ class Transport(virtual.Transport):
     polling_interval = 1
     default_port = None
     connection_errors = (exception.SQSError, socket.error)
-    channel_errors = (exception.SQSDecodeError, )
+    channel_errors = (exception.SQSDecodeError, StdChannelError)
